import 'package:flutter/material.dart';
import '../../plugins/api.dart';
import '../../dialogs/response_dialog.dart';
import '../room/main_page.dart';

class InquiryToManagerPage extends StatefulWidget {
  const InquiryToManagerPage({Key? key}) : super(key: key);

  @override
  _InquiryToManagerPageState createState() => _InquiryToManagerPageState();
}

class _InquiryToManagerPageState extends State<InquiryToManagerPage> {
  final TextEditingController _titleController = TextEditingController();
  final TextEditingController _contentsController = TextEditingController();

  @override
  void dispose() {
    _titleController.dispose();
    _contentsController.dispose();
    super.dispose();
  }

  void _handleSubmit() async {
    final title = _titleController.text.trim();
    final contents = _contentsController.text.trim();

    // 예시: 제목이나 내용이 비어있으면 막기
    if (title.isEmpty || contents.isEmpty) {
      showResponseDialog(context, '안내', '제목과 내용을 입력해주세요.');
      return;
    }

    // 서버에 제출
    try {
      final requestBody = {
        'title': title,
        'contents': contents,
      };
      final serverResponse =
          await Api.serverRequest(uri: '/inquiry/request', body: requestBody);

      if (serverResponse == null) {
        showResponseDialog(context, '문의 전송 실패', '서버 응답이 없습니다.');
      }
      if (serverResponse['result'] == 'OK') {
        final serverResponse1 = serverResponse['response'];
        if (serverResponse1['result'] == 'OK') {
          await showResponseDialog(context, '문의 전송 완료', '문의가 전송되었습니다.');
          Navigator.of(context).pushAndRemoveUntil(
            MaterialPageRoute(builder: (context) => const MainPage()),
            (route) => false,
          );
        } else {
          showResponseDialog(context, '문의 전송 실패', '문의 전송에 실패했습니다.');
        }
      } else {
        showResponseDialog(context, '문의 전송 실패', '문의 전송에 실패했습니다.');
      }
    } catch (e) {
      showResponseDialog(context, '문의 전송 실패', '문의 전송에 실패했습니다.');
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        backgroundColor: Colors.black,
        title: const Text('문의하기', style: TextStyle(color: Colors.white)),
        leading: IconButton(
          icon: const Icon(Icons.arrow_back_ios, color: Colors.white),
          onPressed: () => Navigator.pop(context),
        ),
      ),
      body: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            // 문의 제목 입력
            TextField(
              controller: _titleController,
              maxLength: 100,
              decoration: const InputDecoration(
                labelText: '문의 제목',
                border: OutlineInputBorder(),
              ),
            ),
            const SizedBox(height: 16),
            // 문의 내용 입력(여러 줄 입력 가능)
            TextField(
              controller: _contentsController,
              maxLength: 1000,
              maxLines: 10, // 원하는 높이에 맞게 조절
              decoration: const InputDecoration(
                labelText: '문의 내용',
                border: OutlineInputBorder(),
              ),
            ),
            const SizedBox(height: 16),
            // 제출하기 버튼
            SizedBox(
              width: double.infinity,
              child: ElevatedButton(
                style: ElevatedButton.styleFrom(backgroundColor: Colors.black),
                onPressed: _handleSubmit,
                child: const Text(
                  '제출하기',
                  style: TextStyle(color: Colors.white),
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
